/***********************************************************************

	File:	rand_points.c
	Rev:	a-1
	Date:	02/21/93

	Copyright (c) 1993, by The University of Virginia

************************************************************************

	This program generates random point sets.

************************************************************************

	Modification Log:

	a-1:	02/21/93	dmw
		: Created.

************************************************************************/

#include "steiner.h"
#include <time.h>


/*
 * Global Routines
 */

int			main (int, char **);


/*
 * External References
 */

	/* none */


/*
 * Local Routines
 */

static int32u		cv_number (char *);


/*
 * Local Variables
 */

static char *		me;

/*
 * This routine generates random point sets.
 */

	int
main (

int		argc,		/* IN - argument count. */
char **		argv		/* IN - argument vector. */
)
{
char *			p;
int			i;
int			n;
int32u			x;
int32u			y;
unsigned int		seed;
int			oflag;

	me = argv [0];

	setbuf (stdout, NULL);

	seed = 1;
	n = 10;

	for (i = 1; i < argc; i++) {
		p = argv [i];
		if (p [0] NE '-') {
			n = cv_number (p);
			break;
		}
		switch (p [1]) {
		case 'e':
			oflag = 2;
			break;

		case 'o':
			oflag = 1;
			break;

		case 's':
			seed = cv_number (p + 2);
			break;

		case 'r':
			seed = time (NULL);
			break;
		}
	}

	switch (oflag) {
	case 1:
		printf ("%% rand_points: seed = %lu\n", seed);
		break;

	case 2:
		fprintf (stderr, "%% rand_points: seed = %lu\n", seed);
		break;
	}

	srand (seed);

	for (i = 0; i < n; i++) {
		x = (((int32u) rand ()) >> 2) ^ (((int32u) rand ()) << 3);
		(void) rand ();
		y = (((int32u) rand ()) >> 2) ^ (((int32u) rand ()) << 3);
		x %= MAX_COORD;
		y %= MAX_COORD;
		(void) printf ("%5lu %5lu\n", x, y);
	}

	return (0);
}

/*
 * This routine converts the given string into a number.
 */

	static
	int32u
cv_number (

char *		num_string	/* IN - number to convert. */
)
{
char *		s;
int		c;
int32u		val;

	s = num_string;
	val = 0;
	while ((c = *s++) NE '\0') {
		if (NOT isdigit (c)) {
			(void) fprintf (stderr,
					"%s: `%s' is not a decimal number.\n",
					me, s);
			exit (1);
		}
		val = (val * 10) + (c - '0');
	}

	return (val);
}
